/*
    registry.h
    Copyright (C) 1997-1999 by Richard Dawe

    Registry access functions - part of libwin

    ---

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef __LIBWIN_REGISTRY_H__
#define __LIBWIN_REGISTRY_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <libwin/wintype.h>

/* A couple of Windows constants */
#ifndef ERROR_SUCCESS
#   define ERROR_SUCCESS   0L
#endif

#ifndef ERROR_MORE_DATA
#   define ERROR_MORE_DATA 234L
#endif

/* Registry key constants */
#define HKEY_CLASSES_ROOT        0x80000000 
#define HKEY_CURRENT_USER        0x80000001      
#define HKEY_LOCAL_MACHINE       0x80000002      
#define HKEY_USERS               0x80000003 
#define HKEY_PERFORMANCE_DATA    0x80000004 
#define HKEY_CURRENT_CONFIG      0x80000005 
#define HKEY_DYN_DATA            0x80000006 

/* Registry key types */
#define REG_NONE                          (0)
#define REG_SZ                            (1)   /* Unicode */
#define REG_EXPAND_SZ                     (2)   /*  '   ' but with environment
                                                   variable expansion */
#define REG_BINARY                        (3)   /* Binary */
#define REG_DWORD                         (4)   /* 32 bit number */
#define REG_DWORD_LITTLE_ENDIAN           (4)
#define REG_DWORD_BIG_ENDIAN              (5)   /* 32-bit number, big end */

/* --- Function declarations --- */

/* These were translated from the Regdos functions. */

extern long __RegOpenKey (HKEY, LPCSTR, PHKEY);
extern long __RegCreateKey (HKEY, LPCSTR, PHKEY);
extern long __RegCloseKey (HKEY);
extern long __RegDeleteKey (HKEY, LPCSTR);
extern long __RegDeleteValue (HKEY, LPCSTR);
extern long __RegQueryValue (HKEY, LPCSTR, LPSTR, PLONG);
extern long __RegQueryValueEx (HKEY, LPSTR, LPDWORD, LPDWORD, LPBYTE, LPDWORD);
extern long __RegEnumKey (HKEY, DWORD, LPSTR, DWORD);
extern long __RegEnumValue (HKEY, DWORD, LPSTR, LPDWORD, LPDWORD, LPDWORD, LPBYTE, LPDWORD);
extern long __RegSetValueEx (HKEY, LPCSTR, DWORD, DWORD, CONST BYTE *, DWORD);
extern long __RegSetValue (HKEY, LPCSTR, DWORD, LPCSTR, DWORD);
extern long __RegFlushKey (HKEY);
extern long __RegLoadKey (HKEY, LPCSTR, LPCSTR);
extern long __RegUnLoadKey (HKEY, LPCSTR);
extern long __RegSaveKey (HKEY, LPCSTR, LPSECURITY_ATTRIBUTES);
extern long __RegRestoreKey (HKEY, LPCSTR, DWORD);

/* Windows-style function names */
#define RegOpenKey      __RegOpenKey
#define RegCreateKey    __RegCreateKey
#define RegCloseKey     __RegCloseKey
#define RegDeleteKey    __RegDeleteKey
#define RegQueryValue   __RegQueryValue
#define RegQueryValueEx __RegQueryValueEx
#define RegEnumKey      __RegEnumKey
#define RegEnumValue    __RegEnumValue
#define RegSetValueEx   __RegSetValueEx
#define RegSetValue     __RegSetValue
#define RegFlushKey     __RegFlushKey
#define RegLoadKey      __RegLoadKey
#define RegUnLoadKey    __RegUnLoadKey
#define RegSaveKey      __RegSaveKey
#define RegRestoreKey   __RegRestoreKey

/* libwin-style function names */
#define w95_reg_openkey         __RegOpenKey
#define w95_reg_createkey       __RegCreateKey
#define w95_reg_closekey        __RegCloseKey
#define w95_reg_deletekey       __RegDeleteKey
#define w95_reg_deletevalue     __RegDeleteValue
#define w95_reg_queryvalue      __RegQueryValue
#define w95_reg_queryvalueex    __RegQueryValueEx
#define w95_reg_enumkey         __RegEnumKey
#define w95_reg_enumvalue       __RegEnumValue
#define w95_reg_setvalueex      __RegSetValueEx
#define w95_reg_setvalue        __RegSetValue
#define w95_reg_flushkey        __RegFlushKey
#define w95_reg_loadkey         __RegLoadKey
#define w95_reg_unloadkey       __RegUnLoadKey
#define w95_reg_savekey         __RegSaveKey
#define w95_reg_restorekey      __RegRestoreKey

#ifdef __cplusplus
}
#endif

#endif  /* __LIBWIN_REGISTRY_H__ */
